# unitorch.cli.models.diffusers

## StableProcessor

!!! tip
    **`core/process/diffusion/stable`** is the section for configuration of BartProcessor.

::: unitorch.cli.models.diffusers.StableProcessor

## StableForText2ImageGeneration

!!! tip
    **`core/model/diffusers/text2image/stable`** is the section for configuration of StableForText2ImageGeneration.

::: unitorch.cli.models.diffusers.StableForText2ImageGeneration

## StableForImage2ImageGeneration

!!! tip
    **`core/model/diffusers/image2image/stable`** is the section for configuration of StableForImage2ImageGeneration.

::: unitorch.cli.models.diffusers.StableForImage2ImageGeneration

## StableForImageInpainting

!!! tip
    **`core/model/diffusers/inpainting/stable`** is the section for configuration of StableForImageInpainting.

::: unitorch.cli.models.diffusers.StableForImageInpainting

## StableForImageResolution

!!! tip
    **`core/model/diffusers/resolution/stable`** is the section for configuration of StableForImageResolution.

::: unitorch.cli.models.diffusers.StableForImageResolution

## StableXLProcessor

!!! tip
    **`core/process/diffusion/stable_xl`** is the section for configuration of StableXLProcessor.

::: unitorch.cli.models.diffusers.StableXLProcessor

## StableXLForText2ImageGeneration

!!! tip
    **`core/model/diffusers/text2image/stable_xl`** is the section for configuration of StableXLForText2ImageGeneration.

::: unitorch.cli.models.diffusers.StableXLForText2ImageGeneration

## StableXLForImage2ImageGeneration

!!! tip
    **`core/model/diffusers/image2image/stable_xl`** is the section for configuration of StableXLForImage2ImageGeneration.

::: unitorch.cli.models.diffusers.StableXLForImage2ImageGeneration

## StableXLForImageInpainting

!!! tip
    **`core/model/diffusers/inpainting/stable_xl`** is the section for configuration of StableXLForImageInpainting.

::: unitorch.cli.models.diffusers.StableXLForImageInpainting

## ControlNetProcessor

!!! tip
    **`core/process/diffusion/controlnet`** is the section for configuration of ControlNetProcessor.

::: unitorch.cli.models.diffusers.ControlNetProcessor

## ControlNetForText2ImageGeneration

!!! tip
    **`core/model/diffusers/text2image/controlnet`** is the section for configuration of ControlNetForText2ImageGeneration.

::: unitorch.cli.models.diffusers.ControlNetForText2ImageGeneration

## ControlNetForImage2ImageGeneration

!!! tip
    **`core/model/diffusers/image2image/controlnet`** is the section for configuration of ControlNetForImage2ImageGeneration.

::: unitorch.cli.models.diffusers.ControlNetForImage2ImageGeneration

## ControlNetForImageInpainting

!!! tip
    **`core/model/diffusers/inpainting/controlnet`** is the section for configuration of ControlNetForImageInpainting.

::: unitorch.cli.models.diffusers.ControlNetForImageInpainting

